// Copyright 2000-2020 JetBrains s.r.o. Use of this source code is governed by the Apache 2.0 license that can be found in the LICENSE file.
package com.intellij.internal.statistic.actions

import com.intellij.icons.AllIcons
import com.intellij.idea.ActionsBundle
import com.intellij.internal.statistic.StatisticsBundle
import com.intellij.internal.statistic.eventLog.validator.persistence.BaseEventLogWhitelistPersistence
import com.intellij.internal.statistic.eventLog.validator.persistence.EventLogWhitelistPersistence
import com.intellij.internal.statistic.eventLog.validator.persistence.EventLogWhitelistSettingsPersistence
import com.intellij.notification.Notification
import com.intellij.notification.NotificationType
import com.intellij.openapi.actionSystem.AnActionEvent
import com.intellij.openapi.fileEditor.FileEditorManager
import com.intellij.openapi.project.DumbAwareAction
import com.intellij.openapi.project.Project
import com.intellij.openapi.vfs.VfsUtil
import java.io.File

class OpenWhitelistFileAction(private val myRecorderId: String = "FUS")
  : DumbAwareAction(StatisticsBundle.message("stats.open.0.whitelist.file", myRecorderId),
                    ActionsBundle.message("group.OpenWhitelistFileAction.description"),
                    AllIcons.FileTypes.Config) {
  override fun actionPerformed(e: AnActionEvent) {
    val project = e.project ?: return

    val settings = EventLogWhitelistSettingsPersistence.getInstance().getPathSettings(myRecorderId)
    val file = if (settings != null && settings.isUseCustomPath) {
      File(settings.customPath)
    }
    else {
      BaseEventLogWhitelistPersistence.getDefaultWhitelistFile(myRecorderId, EventLogWhitelistPersistence.WHITE_LIST_DATA_FILE)
    }

    openFileInEditor(file, project)
  }

  companion object {
    fun openFileInEditor(file: File, project: Project) {
      val virtualFile = VfsUtil.findFileByIoFile(file, true)
      if (virtualFile == null) {
        val notification = Notification("FeatureUsageStatistics",
                                        StatisticsBundle.message("stats.feature.usage.statistics"),
                                        StatisticsBundle.message("stats.file.0.does.not.exist", file.absolutePath),
                                        NotificationType.WARNING)
        notification.notify(project)
        return
      }
      FileEditorManager.getInstance(project).openFile(virtualFile, true)
    }
  }

}